These helpers provide the familiar S3 surface for mlxs_lm fits.
Usage
# S3 method for class 'mlxs_lm'
predict(object, newdata = NULL, ...)
# S3 method for class 'mlxs_lm'
fitted(object, ...)
# S3 method for class 'mlxs_lm'
residuals(object, ...)
# S3 method for class 'mlxs_lm'
vcov(object, ...)
# S3 method for class 'mlxs_lm'
confint(
object,
parm,
level = 0.95,
...,
bootstrap = FALSE,
bootstrap_args = list(B = 200L, seed = NULL, progress = FALSE, bootstrap_type = "case")
)
# S3 method for class 'mlxs_lm'
anova(object, ...)
# S3 method for class 'mlxs_anova'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
# S3 method for class 'mlxs_anova'
print(x, ...)
# S3 method for class 'mlxs_anova'
tidy(x, ...)
# S3 method for class 'mlxs_lm'
summary(
object,
bootstrap = FALSE,
bootstrap_args = list(B = 200L, seed = NULL, progress = FALSE, bootstrap_type = "case"),
confint = FALSE,
level = 0.95,
...
)
# S3 method for class 'mlxs_lm'
print(x, ...)
# S3 method for class 'summary.mlxs_lm'
print(x, ...)
# S3 method for class 'mlxs_lm'
model.frame(formula, ...)
# S3 method for class 'mlxs_lm'
model.matrix(object, ...)
# S3 method for class 'mlxs_lm'
terms(x, ...)
# S3 method for class 'mlxs_lm'
nobs(object, ...)
# S3 method for class 'mlxs_lm'
tidy(x, ...)
# S3 method for class 'mlxs_lm'
glance(x, ...)
# S3 method for class 'mlxs_lm'
augment(
x,
data = model.frame(x),
newdata = NULL,
se_fit = FALSE,
output = c("data.frame", "mlx"),
...
)
# S3 method for class 'mlxs_lm'
estfun(x, ..., output = c("matrix", "mlx"))
# S3 method for class 'mlxs_lm'
hatvalues(model, ..., output = c("matrix", "mlx"))
# S3 method for class 'mlxs_lm'
bread(x, ...)Arguments
- object, model
An
mlxs_lmmodel fit.- newdata
Optional data frame for prediction.
- ...
Additional arguments passed to underlying methods.
- parm
Parameter specification for confidence intervals.
- level
Confidence level for intervals.
- bootstrap
Logical; should bootstrap standard errors or confidence intervals be computed?
- bootstrap_args
List of bootstrap configuration options. See
mlxs_boot().- x
An
mlxs_lmmodel fit (for methods with a leadingxargument).- row.names
Optional row names for data frame conversion.
- optional
Logical; passed to
as.data.frame.- confint
Logical; should confidence intervals be included in the summary object?
- formula
An
mlxs_lmobject used in place of formula formodel.frame.- data
Optional data frame for
augment.- se_fit
Logical; should standard errors of fit be included?
- output
Character string; return format ("data.frame", "matrix", "vector" or "mlx"). To make methods from other packages work, the usual default is to return a base R object.